
Changelog
=========

1.0.0 (2022-05-17)
------------------
* First release
* Model for photovoltaic (PV) DERs, including all smart inverter functions defined in IEEE Standard 1547-2018, as well as trip and enter service behaviors
* Output active and reactive power (P, Q) for power flow analysis
* Suitable for both steady-state, quasi-static time series (QSTS) and dynamic simulations
